@@ -1,6 +1,6 @@
-/*  $Id$
+/*  $Id: common.c 6507 2009-01-19 19:00:09Z enrico $
  *
- *  Copyright 2006-2008 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
+ *  Copyright 2006-2009 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -162,7 +162,18 @@ gboolean dict_start_web_query(DictData *dd, const gchar *word)
 	gboolean success = TRUE;
 	gchar *uri;
 
+#if GLIB_CHECK_VERSION(2, 16, 0)
+	gchar *tmp = str_replace(g_strdup(dd->web_url), "{word}", dd->searched_word);
+	uri = g_uri_escape_string(tmp,
+			G_URI_RESERVED_CHARS_GENERIC_DELIMITERS G_URI_RESERVED_CHARS_SUBCOMPONENT_DELIMITERS,
+			FALSE);
+	if (uri != NULL)
+		g_free(tmp);
+	else
+		uri = tmp;
+#else
 	uri = str_replace(g_strdup(dd->web_url), "{word}", dd->searched_word);
+#endif
 	if (! NZV(uri))
 	{
 		xfce_err(_("The search URL is empty. Please check your preferences."));
@@ -199,7 +210,7 @@ void dict_search_word(DictData *dd, const gchar *word)
 	/* sanity checks */
 	if (! NZV(word))
 	{
-		dict_gui_status_add(dd, _("Invalid input."));
+		dict_gui_status_add(dd, _("Invalid input"));
 		return;
 	}
 
@@ -209,7 +220,7 @@ void dict_search_word(DictData *dd, const gchar *word)
 		dd->searched_word = g_locale_to_utf8(word, -1, NULL, NULL, NULL);
 		if (dd->searched_word == NULL || ! g_utf8_validate(dd->searched_word, -1, NULL))
 		{
-			dict_gui_status_add(dd, _("Invalid non-UTF8 input."));
+			dict_gui_status_add(dd, _("Invalid non-UTF8 input"));
 			gtk_entry_set_text(GTK_ENTRY(dd->main_entry), "");
 			dict_gui_set_panel_entry_text(dd, "");
 			return;
@@ -236,7 +247,7 @@ void dict_search_word(DictData *dd, const gchar *word)
 		}
 		case DICTMODE_SPELL:
 		{
-			dict_spell_start_query(dd, dd->searched_word);
+			dict_spell_start_query(dd, dd->searched_word, FALSE);
 			break;
 		}
 		default:
