@@ -1,6 +1,6 @@
-/*  $Id$
+/*  $Id: dictd.c 6521 2009-01-21 16:15:11Z enrico $
  *
- *  Copyright 2006-2008 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
+ *  Copyright 2006-2009 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -222,6 +222,7 @@ static gboolean ignore_short_link(const gchar *str)
 	if (strcmp("f", str) == 0 ||
 		strcmp("m", str) == 0 ||
 		strcmp("n", str) == 0 ||
+		strcmp("vr", str) == 0 ||
 		strcmp("vt", str) == 0 ||
 		strcmp("pl", str) == 0)
 	{
@@ -381,7 +382,7 @@ static gboolean process_server_response(DictData *dd)
 		}
 		case SERVER_NOT_READY:
 		{
-			dict_gui_status_add(dd, _("Server not ready."));
+			dict_gui_status_add(dd, _("The server is not ready."));
 			g_free(dd->query_buffer);
 			return FALSE;
 		}
@@ -409,11 +410,12 @@ static gboolean process_server_response(DictData *dd)
 
 	if (dd->query_status == NOTHING_FOUND)
 	{
-		dict_gui_status_add(dd, _("Ready."));
 
 		gtk_text_buffer_insert(dd->main_textbuffer, &dd->textiter, "\n", 1);
 		tmp = g_strdup_printf(_("No matches could be found for \"%s\"."), dd->searched_word);
-		gtk_text_buffer_insert(dd->main_textbuffer, &dd->textiter, tmp, -1);
+		gtk_text_buffer_insert_with_tags_by_name(dd->main_textbuffer, &dd->textiter,
+			tmp, -1, "error", NULL);
+		dict_gui_status_add(dd, "%s", tmp);
 		g_free(tmp);
 		g_free(dd->query_buffer);
 
@@ -422,19 +424,19 @@ static gboolean process_server_response(DictData *dd)
 		if (NZV(dd->web_url))
 		{
 			gchar *text = g_strdup_printf(
-				_("Do you want to search \"%s\" on the Web using "), dd->searched_word);
+				/* for translators: the first wildcard is the search term, the second wildcard
+				 * is the name of the preferred web search engine */
+				_("Search \"%s\" using \"%s\""),
+				dd->searched_word, _(dict_prefs_get_web_url_label(dd)));
 			gtk_text_buffer_insert(dd->main_textbuffer, &dd->textiter, "\n\n", 2);
-			gtk_text_buffer_insert(dd->main_textbuffer, &dd->textiter, text, -1);
-			gtk_text_buffer_insert(dd->main_textbuffer, &dd->textiter, "\"", 1);
 			gtk_text_buffer_insert_with_tags_by_name(dd->main_textbuffer, &dd->textiter,
-				dict_prefs_get_web_url_label(dd), -1, "link", NULL);
-			gtk_text_buffer_insert(dd->main_textbuffer, &dd->textiter, "\"?", 2);
+				text, -1, "link", NULL);
 			g_free(text);
 		}
 		if (NZV(dd->spell_bin))
 		{
 			gtk_text_buffer_insert(dd->main_textbuffer, &dd->textiter, "\n", 1);
-			dict_spell_start_query(dd, dd->searched_word);
+			dict_spell_start_query(dd, dd->searched_word, TRUE);
 		}
 
 		return FALSE;
@@ -568,7 +570,7 @@ static gchar *get_answer(DictData *dd, gint fd)
 }
 
 
-static void ask_server(DictData *dd)
+static gpointer ask_server(DictData *dd)
 {
 	gint fd, i;
 	static gchar cmd[BUF_SIZE];
@@ -578,7 +580,7 @@ static void ask_server(DictData *dd)
 		dd->query_status = NO_CONNECTION;
 		g_idle_add((GSourceFunc) process_server_response, dd);
 		g_thread_exit(NULL);
-		return;
+		return NULL;
 	}
 	dd->query_is_running = TRUE;
 	dd->query_status = NO_CONNECTION;
@@ -607,6 +609,7 @@ static void ask_server(DictData *dd)
 	g_idle_add((GSourceFunc) process_server_response, dd);
 
 	g_thread_exit(NULL);
+	return NULL;
 }
 
 
