@@ -1,6 +1,6 @@
-/*  $Id$
+/*  $Id: dictd.h 6460 2009-01-14 19:45:58Z enrico $
  *
- *  Copyright 2006-2008 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
+ *  Copyright 2006-2009 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,7 +23,8 @@
 
 
 void dict_dictd_start_query(DictData *dd, const gchar *word);
-gboolean dict_dictd_get_list(GtkWidget *button, DictData *dd);
+void dict_dictd_get_list(GtkWidget *button, DictData *dd);
+void dict_dictd_get_information(GtkWidget *button, DictData *dd);
 
 
 #endif
