@@ -1,6 +1,6 @@
-/*  $Id$
+/*  $Id: gui.c 7317 2009-05-09 08:43:04Z enrico $
  *
- *  Copyright 2006-2008 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
+ *  Copyright 2006-2009 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -42,6 +42,7 @@ static gboolean hovering_over_link = FALSE;
 static GdkCursor *hand_cursor = NULL;
 static GdkCursor *regular_cursor = NULL;
 static gboolean entry_is_dirty = FALSE;
+static const GdkColor error_color = { 0, 0x8000, 0, 0 }; /* dark red */
 
 
 /* all textview_* functions are from the gtk-demo app to get links in the textview working */
@@ -60,13 +61,14 @@ static void textview_follow_if_link(GtkWidget *text_view, GtkTextIter *iter, Dic
 		{
 			gtk_entry_set_text(GTK_ENTRY(dd->main_entry), found_link);
 			dict_search_word(dd, found_link);
-
 			break;
 		}
 		g_object_get(G_OBJECT(tag), "name", &found_link, NULL);
 		if (found_link != NULL && strcmp("link", found_link) == 0)
 		{
-			dict_start_web_query(dd, dd->searched_word);
+			gboolean browser_started = dict_start_web_query(dd, dd->searched_word);
+			if (browser_started && dd->is_plugin)
+				gtk_widget_hide(dd->window);
 			g_free(found_link);
 			break;
 		}
@@ -128,13 +130,13 @@ static gboolean textview_event_after(GtkWidget *text_view, GdkEvent *ev, DictDat
 }
 
 
-static void textview_set_cursor_if_appropriate(GtkTextView *text_view, gint x, gint y)
+static void textview_set_cursor_if_appropriate(GtkTextView *view, gint x, gint y, GdkWindow *win)
 {
 	GSList *tags = NULL, *tagp = NULL;
 	GtkTextIter iter;
 	gboolean hovering = FALSE;
 
-	gtk_text_view_get_iter_at_location(text_view, &iter, x, y);
+	gtk_text_view_get_iter_at_location(view, &iter, x, y);
 
 	tags = gtk_text_iter_get_tags(&iter);
 	for (tagp = tags;  tagp != NULL;  tagp = tagp->next)
@@ -161,11 +163,9 @@ static void textview_set_cursor_if_appropriate(GtkTextView *text_view, gint x, g
 		hovering_over_link = hovering;
 
 		if (hovering_over_link)
-			gdk_window_set_cursor(gtk_text_view_get_window(
-				text_view, GTK_TEXT_WINDOW_TEXT), hand_cursor);
+			gdk_window_set_cursor(win, hand_cursor);
 		else
-			gdk_window_set_cursor(gtk_text_view_get_window(
-				text_view, GTK_TEXT_WINDOW_TEXT), regular_cursor);
+			gdk_window_set_cursor(win, regular_cursor);
 	}
 
 	if (tags)
@@ -180,7 +180,7 @@ static gboolean textview_motion_notify_event(GtkWidget *text_view, GdkEventMotio
 	gtk_text_view_window_to_buffer_coords(GTK_TEXT_VIEW(text_view), GTK_TEXT_WINDOW_WIDGET,
 		event->x, event->y, &x, &y);
 
-	textview_set_cursor_if_appropriate(GTK_TEXT_VIEW(text_view), x, y);
+	textview_set_cursor_if_appropriate(GTK_TEXT_VIEW(text_view), x, y, event->window);
 
 	gdk_window_get_pointer(text_view->window, NULL, NULL, NULL);
 
@@ -197,7 +197,7 @@ static gboolean textview_visibility_notify_event(GtkWidget *text_view, GdkEventV
 	gtk_text_view_window_to_buffer_coords(GTK_TEXT_VIEW(text_view),
 		GTK_TEXT_WINDOW_WIDGET, wx, wy, &bx, &by);
 
-	textview_set_cursor_if_appropriate(GTK_TEXT_VIEW(text_view), bx, by);
+	textview_set_cursor_if_appropriate(GTK_TEXT_VIEW(text_view), bx, by, event->window);
 
 	return FALSE;
 }
@@ -262,6 +262,8 @@ static gboolean textview_button_press_cb(GtkTextView *view, GdkEventButton *even
 		gtk_text_view_window_to_buffer_coords(view, GTK_TEXT_WINDOW_TEXT, event->x, event->y, &x, &y);
 		gtk_text_view_get_iter_at_location(view, &iter, x, y);
 		gtk_text_buffer_move_mark(dd->main_textbuffer, dd->mark_click, &iter);
+
+		gdk_window_set_cursor(event->window, regular_cursor);
 	}
 
 	return FALSE;
@@ -287,6 +289,8 @@ void dict_gui_status_add(DictData *dd, const gchar *format, ...)
 
 	gtk_statusbar_pop(GTK_STATUSBAR(dd->statusbar), 1);
 	gtk_statusbar_push(GTK_STATUSBAR(dd->statusbar), 1, string);
+	if (dd->verbose_mode)
+		g_message("%s", string);
 }
 
 
@@ -325,7 +329,7 @@ static void entry_icon_pressed_cb(SexyIconEntry *entry, gint icon_pos, gint butt
 		dict_gui_clear_text_buffer(dd);
 		gtk_entry_set_text(GTK_ENTRY(dd->main_entry), "");
 		dict_gui_set_panel_entry_text(dd, "");
-		dict_gui_status_add(dd, _("Ready."));
+		dict_gui_status_add(dd, _("Ready"));
 	}
 }
 
@@ -511,7 +515,6 @@ void dict_gui_finalize(DictData *dd)
 {
 	if (hand_cursor)
 		gdk_cursor_unref(hand_cursor);
-
 	if (regular_cursor)
 		gdk_cursor_unref(regular_cursor);
 }
@@ -587,19 +590,19 @@ void dict_gui_create_main_window(DictData *dd)
 	gtk_widget_show(label);
 	gtk_box_pack_start(GTK_BOX(method_chooser), label, FALSE, FALSE, 6);
 
-	radio = gtk_radio_button_new_with_mnemonic(NULL, _("_Dict"));
+	radio = gtk_radio_button_new_with_mnemonic(NULL, _("_Dictionary Server"));
 	gtk_widget_show(radio);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio), (dd->mode_in_use == DICTMODE_DICT));
 	g_signal_connect(radio, "toggled", G_CALLBACK(search_mode_dict_toggled), dd);
 	gtk_box_pack_start(GTK_BOX(method_chooser), radio, FALSE, FALSE, 6);
 
-	radio = gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(radio), _("_Web"));
+	radio = gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(radio), _("_Web Service"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio), (dd->mode_in_use == DICTMODE_WEB));
 	g_signal_connect(radio, "toggled", G_CALLBACK(search_mode_web_toggled), dd);
 	gtk_widget_show(radio);
 	gtk_box_pack_start(GTK_BOX(method_chooser), radio, FALSE, FALSE, 6);
 
-	radio = gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(radio), _("_Spell Check"));
+	radio = gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(radio), _("_Spell Checker"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio), (dd->mode_in_use == DICTMODE_SPELL));
 	g_signal_connect(radio, "toggled", G_CALLBACK(search_mode_spell_toggled), dd);
 	gtk_widget_show(radio);
@@ -629,6 +632,10 @@ void dict_gui_create_main_window(DictData *dd)
 			"style", PANGO_STYLE_ITALIC,
 			"indent", 10,
 			"pixels-below-lines", 5, NULL);
+	gtk_text_buffer_create_tag(dd->main_textbuffer,
+			"error",
+			"style", PANGO_STYLE_ITALIC,
+			"foreground-gdk", &error_color, NULL);
 	dd->phon_tag = gtk_text_buffer_create_tag(dd->main_textbuffer,
 			"phonetic",
 			"style", PANGO_STYLE_ITALIC,
@@ -717,7 +724,7 @@ void dict_gui_about_dialog(GtkWidget *widget, DictData *dd)
 		"destroy-with-parent", TRUE,
 		"authors", authors,
 		"comments", _("A client program to query different dictionaries."),
-		"copyright", _("Copyright \302\251 2006-2008 Enrico Tröger"),
+		"copyright", _("Copyright \302\251 2006-2009 Enrico Tröger"),
 		"website", "http://goodies.xfce.org/projects/applications/xfce4-dict",
 		"logo", logo,
 		"translator-credits", _("translator-credits"),
