@@ -1,6 +1,6 @@
-/*  $Id$
+/*  $Id: xfce4-dict.c 6507 2009-01-19 19:00:09Z enrico $
  *
- *  Copyright 2006-2008 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
+ *  Copyright 2006-2009 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -44,6 +44,7 @@ static gboolean focus_panel_entry = FALSE;
 static gboolean mode_dict = FALSE;
 static gboolean mode_web = FALSE;
 static gboolean mode_spell = FALSE;
+static gboolean verbose_mode = FALSE;
 
 static GOptionEntry cli_options[] =
 {
@@ -53,6 +54,7 @@ static GOptionEntry cli_options[] =
 	{ "text-field", 't', 0, G_OPTION_ARG_NONE, &focus_panel_entry, N_("Grab the focus on the text field in the panel"), NULL },
 	{ "ignore-plugin", 'i', 0, G_OPTION_ARG_NONE, &ignore_plugin, N_("Start stand-alone application even if the panel plugin is loaded"), NULL },
 	{ "clipboard", 'c', 0, G_OPTION_ARG_NONE, &use_clipboard, N_("Grabs the PRIMARY selection content and uses it as search text"), NULL },
+	{ "verbose", 'v', 0, G_OPTION_ARG_NONE, &verbose_mode, N_("Be verbose"), NULL },
 	{ "version", 'V', 0, G_OPTION_ARG_NONE, &show_version, N_("Show version information"), NULL },
 	{ NULL, 0, 0, 0, NULL, NULL, NULL }
 };
@@ -140,7 +142,7 @@ gint main(gint argc, gchar *argv[])
 	if (show_version)
 	{
 		g_print("%s %s (Xfce %s)\n\n", PACKAGE, PACKAGE_VERSION, xfce_version_string());
-		g_print("%s\n", "Copyright (c) 2006-2008");
+		g_print("%s\n", "Copyright (c) 2006-2009");
 		g_print("\tEnrico Tröger <enrico@xfce.org>\n\n");
 		g_print(_("Please report bugs to <%s>."), PACKAGE_BUGREPORT);
 		g_print("\n");
@@ -175,6 +177,7 @@ gint main(gint argc, gchar *argv[])
 
 	dd = dict_create_dictdata();
 	dd->is_plugin = FALSE;
+	dd->verbose_mode = verbose_mode;
 
 	g_thread_init(NULL);
 
@@ -198,7 +201,7 @@ gint main(gint argc, gchar *argv[])
 		dict_search_word(dd, search_text);
 	}
 	else
-		dict_gui_status_add(dd, _("Ready."));
+		dict_gui_status_add(dd, _("Ready"));
 
 	g_free(search_text);
 
